pywws.Tasks — pywws 12.12_e27456b documentation

### Navigation

- index
- modules |
- suivant |
- précédent |
- pywws 12.12_e27456b documentation »
- Python programs and modules »

# pywws.Tasks

Routines to perform common tasks such as plotting gaphs or uploading files.

Classes

`RegularTasks`(params, calib_data, ...) |

class `pywws.Tasks.` `RegularTasks`(params, calib_data, hourly_data, daily_data, monthly_data)
  `has_live_tasks`()
  `do_live`(data)
  `do_tasks`()
  `do_twitter`(template, data=None)
  `do_plot`(template)
  `do_template`(template, data=None)

### Navigation

- index
- modules |
- suivant |
- précédent |
- pywws 12.12_e27456b documentation »
- Python programs and modules »